summaryrefslogtreecommitdiff
path: root/config/routes/project.rb
diff options
context:
space:
mode:
authorDouwe Maan <douwe@selenight.nl>2017-05-22 20:08:33 -0500
committerDouwe Maan <douwe@selenight.nl>2017-05-23 20:38:35 -0500
commitb0498c176fa134761d899c9b369be12f1ca789c5 (patch)
treedcf223813e0b1bb5932a94793a6f827771517a96 /config/routes/project.rb
parented16c351c5acdf1ad2e401e72490320d06af6e91 (diff)
downloadgitlab-ce-b0498c176fa134761d899c9b369be12f1ca789c5.tar.gz
Remove changes that are not absolutely necessarydm-fix-routes
Diffstat (limited to 'config/routes/project.rb')
-rw-r--r--config/routes/project.rb10
1 files changed, 5 insertions, 5 deletions
diff --git a/config/routes/project.rb b/config/routes/project.rb
index a2bc63a4734..9fe8372edf9 100644
--- a/config/routes/project.rb
+++ b/config/routes/project.rb
@@ -13,16 +13,16 @@ constraints(ProjectUrlConstrainer.new) do
# Otherwise, Rails will overwrite the constraint with `/.+?/`,
# which breaks some of our wildcard routes like `/blob/*id`
# and `/tree/*id` that depend on the negative lookahead inside
# `Gitlab::PathRegex.full_namespace_route_regex`, which helps the router
# determine whether a certain path segment is part of `*namespace_id`,
# `:project_id`, or `*id`.
#
# See https://github.com/rails/rails/blob/v4.2.8/actionpack/lib/action_dispatch/routing/mapper.rb#L155
scope(path: '*namespace_id',
as: :namespace,
- namespace_id: Gitlab::PathRegex.full_namespace_route_regex) do
+ namespace_id: Gitlab::Regex.namespace_route_regex) do
scope(path: ':project_id',
- constraints: { project_id: Gitlab::PathRegex.project_route_regex },
+ constraints: { project_id: Gitlab::Regex.project_route_regex },
module: :projects,
as: :project) do
@@ -329,7 +329,7 @@ constraints(ProjectUrlConstrainer.new) do
resources :runner_projects, only: [:create, :destroy]
resources :badges, only: [:index] do
collection do
- scope '*ref', constraints: { ref: Gitlab::PathRegex.git_reference_regex } do
+ scope '*ref', constraints: { ref: Gitlab::Regex.git_reference_regex } do
constraints format: /svg/ do
get :build
get :coverage
@@ -352,7 +352,7 @@ constraints(ProjectUrlConstrainer.new) do
resources(:projects,
path: '/',
- constraints: { id: Gitlab::PathRegex.project_route_regex },
+ constraints: { id: Gitlab::Regex.project_route_regex },
only: [:edit, :show, :update, :destroy]) do
member do
put :transfer
@@ -13,16 +13,16 @@ constraints(ProjectUrlConstrainer.new) do
# which breaks some of our wildcard routes like `/blob/*id`
# and `/tree/*id` that depend on the negative lookahead inside
- # `Gitlab::PathRegex.full_namespace_route_regex`, which helps the router
+ # `Gitlab::Regex.namespace_route_regex`, which helps the router
# determine whether a certain path segment is part of `*namespace_id`,
# `:project_id`, or `*id`.